@@ -1,4 +1,3 @@
-from asyncio.events import AbstractEventLoop
 from copy import deepcopy
 from typing import Generator, Type
 from unittest.mock import AsyncMock, patch
@@ -11,10 +10,9 @@ from ..mocks.mock_zeroconf import MockServiceBrowser
 
 
 @pytest.fixture()
-def mock_device(request: pytest.FixtureRequest, event_loop: AbstractEventLoop) -> Generator[Device, None, None]:
+def mock_device(request: pytest.FixtureRequest) -> Generator[Device, None, None]:
     device = Device(ip=request.cls.ip)
     device._info = deepcopy(request.cls.device_info)
-    device._loop = event_loop
     device._session = AsyncMock()
     device._zeroconf = AsyncMock()
     yield device
